@@ -9,13 +9,13 @@ module Sass::Constant # :nodoc:
       @operand2 = operand2
       @operator = operator
     end
-    
+
     def to_s
       self.perform.to_s
     end
-    
+
     protected
-    
+
     def perform
       literal1 = @operand1.perform
       literal2 = @operand2.perform
@@ -23,7 +23,7 @@ module Sass::Constant # :nodoc:
         literal1.send(@operator, literal2)
       rescue NoMethodError => e
         raise e unless e.name.to_s == @operator.to_s
-        raise Sass::SyntaxError.new("Undefined operation: \"#{literal1} #{@operator} #{literal2}\"")
+        raise Sass::SyntaxError.new("Undefined operation: \"#{literal1} #{@operator} #{literal2}\".")
       end
     end
   end
